from setuptools import setup, find_packages

setup(
    name="my_async_package",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[],
    tests_require=["pytest", "pytest-asyncio"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
